/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#include "DNASequence.h"

namespace GB2 {
    
DNASequence::DNASequence(const QString& name, const QByteArray& s, DNAAlphabet* a) : seq(s), alphabet(a) {
    if (!name.isEmpty()) {
        info.insert(DNAInfo::ID, name);
    }
}


} //namespace
